@@ -24,9 +24,15 @@ sub prepare {
         my ($options) = @_;
 
         my $dstdir = tempdir( CLEANUP => 1 );
+        my $cmd;
+
         my $srcdir = module_dir('Benchmark::Perl::Formance::Plugin::P6STD');
         print STDERR "# Prepare files in $dstdir ...\n" if $options->{verbose} >= 3;
         dircopy($srcdir, $dstdir);
+
+        $cmd = "cd $dstdir ; make PERL=$^X";
+        print STDERR "#   $cmd\n" if $options->{verbose} && $options->{verbose} > 3;
+        qx"$cmd";
         return $dstdir;
 }
 
@@ -76,7 +82,7 @@ sub main {
 
         my $workdir = prepare($options);
         return {
-                gimme5 => gimme5($workdir, $options),
+                #gimme5 => gimme5($workdir, $options),
                 viv    => viv($workdir, $options),
                };
 }
